
from distutils.core import setup

setup(name='easy_coursera',
      version='1.0.2',
      description='Download all lecture videos with a single click!',
      url='https://github.com/beingcooper/EasyCoursera',
      author='Sachin Sharma',
      author_email='sachin.sharma0728@gmailcom',
      license='MIT',
      packages=['easy_coursera'])
  